pub struct EightChain<T>where
T: SingleChainThermodynamics,{
pub bulk_modulus: Quantity<Stress>,
pub shear_modulus: Quantity<Stress>,
pub single_chain_model: T,
}Expand description
The eight-chain hyperelastic solid constitutive model.
Parameters
- The bulk modulus $
\kappa$. - The shear modulus $
\mu$. - The single-chain model.
External variables
- The deformation gradient $
\mathbf{F}$.
Internal variables
- None.
Notes
- The nondimensional end-to-end length per link of a chain is $
\gamma=\sqrt{\mathrm{tr}(\mathbf{B}^*)/3N_b}$. - The nondimensional force is given by the single-chain model as $
\eta=\eta(\gamma)$. - The initial values are given by $
\gamma_0=\sqrt{1/3N_b}$ and $\eta_0=\eta(\gamma_0)$. - The eight-chain model reduces to the Arruda-Boyce model when $
\eta=\mathcal{L}^{-1}(\gamma)$.
Fields
bulk_modulus: Quantity<Stress>The bulk modulus $\kappa$.
shear_modulus: Quantity<Stress>The shear modulus $\mu$.
single_chain_model: TThe single-chain model.
Implementations
Sourceimpl<T> EightChain<T>where
T: SingleChainThermodynamics,
impl<T> EightChain<T>where
T: SingleChainThermodynamics,
Sourcepub fn number_of_links(&self) -> Scalar
pub fn number_of_links(&self) -> Scalar
Returns the number of links in a single chain.
Sourcepub fn single_chain_model(&self) -> &T
pub fn single_chain_model(&self) -> &T
Returns the single-chain model.